@@ -32,7 +32,7 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.31 2007/07/26 23:14:02 hoa Exp $
+ * $Id: mailsmtp.c,v 1.32 2007/10/27 10:08:26 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,6 +44,10 @@
 #include "base64.h"
 #include "mail.h"
 
+#ifdef WIN32
+#	include "win_etpan.h"
+#endif
+
 #ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
