@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_socket.c,v 1.16 2006/06/26 11:50:28 hoa Exp $
+ * $Id: mailsmtp_socket.c,v 1.18 2006/12/26 13:13:25 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -82,7 +82,14 @@ int mailsmtp_socket_connect(mailsmtp * session,
   return mailsmtp_connect(session, stream);
 }
 
-int mailsmtp_socket_starttls(mailsmtp * session) {
+int mailsmtp_socket_starttls(mailsmtp * session)
+{
+  return mailsmtp_socket_starttls_with_callback(session, NULL, NULL);
+}
+
+int mailsmtp_socket_starttls_with_callback(mailsmtp * session,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
+{
   int r;
   int fd;
   mailstream_low * low;
@@ -97,9 +104,9 @@ int mailsmtp_socket_starttls(mailsmtp * session) {
   if (fd == -1)
     return MAILSMTP_ERROR_STREAM;
 
-  new_low = mailstream_low_tls_open(fd);
+  new_low = mailstream_low_tls_open_with_callback(fd, callback, data);
   if (new_low == NULL)
-    return MAILSMTP_ERROR_STREAM;
+    return MAILSMTP_ERROR_SSL;
 
   mailstream_low_free(low);
   mailstream_set_low(session->stream, new_low);
